@@ -132,8 +132,9 @@ window_resize (GtkSourceCompletionInfo *info)
 	if (info->priv->widget != NULL)
 	{
 		/* Try to resize to fit widget, if necessary */
-		gtk_widget_size_request (info->priv->widget, &req);
-		
+		gtk_widget_get_preferred_size (info->priv->widget,
+		                               &req, NULL);
+
 		get_scrolled_window_sizing (info, &border, &hscroll, &vscroll);
 		off = (gtk_container_get_border_width (GTK_CONTAINER (info)) + border) * 2;
 
@@ -287,26 +288,20 @@ gtk_source_completion_info_show (GtkWidget *widget)
 }
 
 static gboolean
-gtk_source_completion_info_expose (GtkWidget      *widget,
-                                   GdkEventExpose *expose)
+gtk_source_completion_info_draw (GtkWidget *widget,
+                                 cairo_t   *cr)
 {
-	GtkAllocation allocation;
+	GTK_WIDGET_CLASS (gtk_source_completion_info_parent_class)->draw (widget, cr);
 
-	GTK_WIDGET_CLASS (gtk_source_completion_info_parent_class)->expose_event (widget, expose);
-
-	gtk_widget_get_allocation (widget, &allocation);
-	
 	gtk_paint_shadow (gtk_widget_get_style (widget),
-			  gtk_widget_get_window (widget),
+			  cr,
 			  GTK_STATE_NORMAL,
 			  GTK_SHADOW_OUT,
-			  NULL,
 			  widget,
 			  NULL,
-			  allocation.x,
-			  allocation.y,
-			  allocation.width,
-			  allocation.height);
+			  0, 0,
+			  gtk_widget_get_allocated_width (widget),
+			  gtk_widget_get_allocated_height (widget));
 
 	return FALSE;
 }
@@ -322,7 +317,7 @@ gtk_source_completion_info_class_init (GtkSourceCompletionInfoClass *klass)
 	object_class->finalize = gtk_source_completion_info_finalize;
 	
 	widget_class->show = gtk_source_completion_info_show;
-	widget_class->expose_event = gtk_source_completion_info_expose;
+	widget_class->draw = gtk_source_completion_info_draw;
 	
 	/**
 	 * GtkSourceCompletionInfo::show-info:
@@ -504,8 +499,8 @@ use_scrolled_window (GtkSourceCompletionInfo *info,
 	
 	mw = info->priv->max_width;
 	mh = info->priv->max_height;
-	gtk_widget_size_request (widget, &req);
-	
+	gtk_widget_get_preferred_size (widget, &req, NULL);
+
 	return (mw != -1 && mw < req.width) || (mh != -1 && mh < req.height);
 }
 
