@@ -1,22 +1,22 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/*  gtksourcemark.c
+/* gtksourcemark.c
+ * This file is part of GtkSourceView
  *
- *  Copyright (C) 2007 by:
- *		Johannes Schmid <jhs@gnome.org>
+ * Copyright (C) 2007 - Johannes Schmid <jhs@gnome.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * GtkSourceView is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ * GtkSourceView is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "gtksourcemark.h"
@@ -211,7 +211,7 @@ gtk_source_mark_get_category (GtkSourceMark *mark)
  *
  * If @category is %NULL, looks for marks of any category.
  *
- * Returns: the next #GtkSourceMark, or %NULL.
+ * Returns: (transfer none): the next #GtkSourceMark, or %NULL.
  *
  * Since: 2.2
  */
@@ -241,7 +241,7 @@ gtk_source_mark_next (GtkSourceMark *mark,
  * 
  * If @category is %NULL, looks for marks of any category
  *
- * Returns: the previous #GtkSourceMark, or %NULL.
+ * Returns: (transfer none): the previous #GtkSourceMark, or %NULL.
  *
  * Since: 2.2
  */
